@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -26,17 +26,9 @@
 
 G_BEGIN_DECLS
 
-int g_mime_strcase_equal (gconstpointer v, gconstpointer v2);
+G_GNUC_INTERNAL int g_mime_strcase_equal (gconstpointer v, gconstpointer v2);
 
-guint g_mime_strcase_hash (gconstpointer key);
-
-#ifndef HAVE_STRNCASECMP
-int strncasecmp (const char *s1, const char *s2, size_t n);
-#endif
-
-#ifndef HAVE_STRCASECMP
-int strcasecmp (const char *s1, const char *s2);
-#endif
+G_GNUC_INTERNAL guint g_mime_strcase_hash (gconstpointer key);
 
 G_END_DECLS
 
