@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -51,6 +51,24 @@ typedef enum {
 } GMimeContentEncoding;
 
 
+/**
+ * GMimeEncodingConstraint:
+ * @GMIME_ENCODING_CONSTRAINT_7BIT: The stream data must fit within the 7bit ASCII range.
+ * @GMIME_ENCODING_CONSTRAINT_8BIT: The stream data may have bytes with the high bit set, but no null bytes.
+ * @GMIME_ENCODING_CONSTRAINT_BINARY: The stream may contain any binary data.
+ *
+ * Used with functions like g_mime_filter_best_encoding() and
+ * g_mime_object_encode() as the 'constraint' argument. These values
+ * provide a means of letting the filter know what the encoding
+ * constraints are for the stream.
+ **/
+typedef enum {
+	GMIME_ENCODING_CONSTRAINT_7BIT,
+	GMIME_ENCODING_CONSTRAINT_8BIT,
+	GMIME_ENCODING_CONSTRAINT_BINARY
+} GMimeEncodingConstraint;
+
+
 GMimeContentEncoding g_mime_content_encoding_from_string (const char *str);
 const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 
@@ -78,7 +96,7 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
  * Returns: the number of output bytes needed to encode an input buffer
  * of size @x using the quoted-printable encoding.
  **/
-#define GMIME_QP_ENCODE_LEN(x)     ((size_t) ((((x) / 24) * 74) + 74))
+#define GMIME_QP_ENCODE_LEN(x)     ((size_t) ((((x) + 1) * 3) + 1))
 
 
 /**
@@ -91,13 +109,13 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
  * Returns: the number of output bytes needed to uuencode an input
  * buffer of size @x.
  **/
-#define GMIME_UUENCODE_LEN(x)      ((size_t) (((((x) + 2) / 45) * 62) + 64))
+#define GMIME_UUENCODE_LEN(x)      ((size_t) (((((x) + 2) / 45) * 62) + 62))
 
 
 /**
  * GMIME_UUDECODE_STATE_INIT:
  *
- * Initial state for the g_mime_encoding_uudecode_step() function.
+ * Initial state for the g_mime_utils_uudecode_step() function.
  **/
 #define GMIME_UUDECODE_STATE_INIT   (0)
 
@@ -105,7 +123,7 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 /**
  * GMIME_UUDECODE_STATE_BEGIN:
  *
- * State for the g_mime_encoding_uudecode_step() function, denoting that
+ * State for the g_mime_utils_uudecode_step() function, denoting that
  * the 'begin' line has been found.
  **/
 #define GMIME_UUDECODE_STATE_BEGIN  (1 << 16)
@@ -114,7 +132,7 @@ const char *g_mime_content_encoding_to_string (GMimeContentEncoding encoding);
 /**
  * GMIME_UUDECODE_STATE_END:
  *
- * State for the g_mime_encoding_uudecode_step() function, denoting that
+ * State for the g_mime_utils_uudecode_step() function, denoting that
  * the end of the UU encoded block has been found.
  **/
 #define GMIME_UUDECODE_STATE_END    (1 << 17)
