@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -280,16 +280,17 @@ g_mime_filter_best_charset (GMimeFilterBest *best)
 
 /**
  * g_mime_filter_best_encoding:
- * @best: best filter
- * @required: encoding that all data must fit within
+ * @best: a #GMimeFilterBest
+ * @constraint: a #GMimeEncodingConstraint
  *
- * Calculates the best Content-Transfer-Encoding for the stream
- * filtered through @best that fits within the @required encoding.
+ * Calculates the most efficient Content-Transfer-Encoding for the
+ * stream filtered through @best that fits within the encoding
+ * @constraint.
  *
  * Returns: the best encoding for the stream filtered by @best.
  **/
 GMimeContentEncoding
-g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
+g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeEncodingConstraint constraint)
 {
 	GMimeContentEncoding encoding = GMIME_CONTENT_ENCODING_DEFAULT;
 	
@@ -298,12 +299,12 @@ g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
 	if (!(best->flags & GMIME_FILTER_BEST_ENCODING))
 		return GMIME_CONTENT_ENCODING_DEFAULT;
 	
-	switch (required) {
-	case GMIME_BEST_ENCODING_7BIT:
+	switch (constraint) {
+	case GMIME_ENCODING_CONSTRAINT_7BIT:
 		if (best->count0 > 0) {
 			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->count8 > 0) {
-			if (best->count8 >= (best->total * 17 / 100))
+			if (best->count8 >= (unsigned int) (best->total * (17.0 / 100.0)))
 				encoding = GMIME_CONTENT_ENCODING_BASE64;
 			else
 				encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
@@ -311,14 +312,14 @@ g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
 			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
-	case GMIME_BEST_ENCODING_8BIT:
+	case GMIME_ENCODING_CONSTRAINT_8BIT:
 		if (best->count0 > 0) {
 			encoding = GMIME_CONTENT_ENCODING_BASE64;
 		} else if (best->maxline > 998) {
 			encoding = GMIME_CONTENT_ENCODING_QUOTEDPRINTABLE;
 		}
 		break;
-	case GMIME_BEST_ENCODING_BINARY:
+	case GMIME_ENCODING_CONSTRAINT_BINARY:
 		if (best->count0 + best->count8 > 0)
 			encoding = GMIME_CONTENT_ENCODING_BINARY;
 		break;
@@ -329,4 +330,3 @@ g_mime_filter_best_encoding (GMimeFilterBest *best, GMimeBestEncoding required)
 	
 	return encoding;
 }
-
