@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -39,14 +39,10 @@
 #include <sys/utsname.h>    /* for uname() */
 #endif
 #include <sys/types.h>
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>         /* Unix header for getpid() */
-#endif
 #ifdef G_OS_WIN32
 #include <winsock2.h>
 #include <ws2tcpip.h>
-#include <process.h>
-#define getpid() _getpid()
 #endif
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
@@ -476,7 +472,7 @@ mktime_utc (struct tm *tm)
 	tm->tm_isdst = -1;
 	tt = mktime (tm);
 	
-#if defined (G_OS_WIN32) && !defined (__MINGW32__)
+#if defined (G_OS_WIN32)
 	_get_timezone (&tz);
 	if (tm->tm_isdst > 0) {
 		int dst;
@@ -1670,11 +1666,9 @@ g_mime_utils_decode_8bit (const char *text, size_t len)
 		
 		while (inptr < inend) {
 			if (is_ascii (*inptr))
-				*outbuf++ = *inptr;
+				*outbuf++ = *inptr++;
 			else
 				*outbuf++ = '?';
-			
-			inptr++;
 		}
 		
 		*outbuf++ = '\0';
@@ -1877,7 +1871,7 @@ g_mime_utils_header_decode_text (const char *text)
 			word = inptr;
 			ascii = TRUE;
 			
-			if (G_UNLIKELY (enable_rfc2047_workarounds)) {
+			if (enable_rfc2047_workarounds) {
 				if (!strncmp (inptr, "=?", 2)) {
 					inptr += 2;
 					
@@ -1899,15 +1893,8 @@ g_mime_utils_header_decode_text (const char *text)
 						inptr++;
 					}
 					
-					if (*inptr == '\0') {
-						/* didn't find an end marker... */
-						inptr = word + 2;
-						ascii = TRUE;
-						
-						goto non_rfc2047;
-					}
-					
-					inptr += 2;
+					if (!strncmp (inptr, "?=", 2))
+						inptr += 2;
 				} else {
 				non_rfc2047:
 					/* stop if we encounter a possible rfc2047 encoded
@@ -1988,10 +1975,9 @@ g_mime_utils_header_decode_text (const char *text)
 char *
 g_mime_utils_header_decode_phrase (const char *phrase)
 {
-	gboolean enable_rfc2047_workarounds = _g_mime_enable_rfc2047_workarounds ();
 	register const char *inptr = phrase;
 	gboolean encoded = FALSE;
-	const char *lwsp, *word;
+	const char *lwsp, *text;
 	size_t nlwsp, n;
 	gboolean ascii;
 	char *decoded;
@@ -2009,53 +1995,14 @@ g_mime_utils_header_decode_phrase (const char *phrase)
 		
 		nlwsp = (size_t) (inptr - lwsp);
 		
-		word = inptr;
+		text = inptr;
 		if (is_atom (*inptr)) {
-			if (G_UNLIKELY (enable_rfc2047_workarounds)) {
-				/* Make an extra effort to detect and
-				 * separate encoded-word tokens that
-				 * have been merged with other
-				 * words. */
-				
-				if (!strncmp (inptr, "=?", 2)) {
-					inptr += 2;
-					
-					/* skip past the charset (if one is even declared, sigh) */
-					while (*inptr && *inptr != '?')
-						inptr++;
-					
-					/* sanity check encoding type */
-					if (inptr[0] != '?' || !strchr ("BbQq", inptr[1]) || inptr[2] != '?')
-						goto non_rfc2047;
-					
-					inptr += 3;
-					
-					/* find the end of the rfc2047 encoded word token */
-					while (*inptr && strncmp (inptr, "?=", 2) != 0)
-						inptr++;
-					
-					if (*inptr == '\0') {
-						/* didn't find an end marker... */
-						inptr = word + 2;
-						goto non_rfc2047;
-					}
-					
-					inptr += 2;
-				} else {
-				non_rfc2047:
-					/* stop if we encounter a possible rfc2047 encoded
-					 * token even if it's inside another word, sigh. */
-					while (is_atom (*inptr) && strncmp (inptr, "=?", 2) != 0)
-						inptr++;
-				}
-			} else {
-				while (is_atom (*inptr))
-					inptr++;
-			}
+			while (is_atom (*inptr))
+				inptr++;
 			
-			n = (size_t) (inptr - word);
-			if (is_rfc2047_encoded_word (word, n)) {
-				if ((decoded = rfc2047_decode_word (word, n))) {
+			n = (size_t) (inptr - text);
+			if (is_rfc2047_encoded_word (text, n)) {
+				if ((decoded = rfc2047_decode_word (text, n))) {
 					/* rfc2047 states that you must ignore all
 					 * whitespace between encoded words */
 					if (!encoded)
@@ -2079,20 +2026,20 @@ g_mime_utils_header_decode_phrase (const char *phrase)
 			g_string_append_len (out, lwsp, nlwsp);
 			
 			ascii = TRUE;
-			while (*inptr && !is_lwsp (*inptr) && !is_atom (*inptr)) {
+			while (*inptr && !is_lwsp (*inptr)) {
 				ascii = ascii && is_ascii (*inptr);
 				inptr++;
 			}
 			
-			n = (size_t) (inptr - word);
+			n = (size_t) (inptr - text);
 			
 			if (!ascii) {
 				/* *sigh* I hate broken mailers... */
-				decoded = g_mime_utils_decode_8bit (word, n);
+				decoded = g_mime_utils_decode_8bit (text, n);
 				g_string_append (out, decoded);
 				g_free (decoded);
 			} else {
-				g_string_append_len (out, word, n);
+				g_string_append_len (out, text, n);
 			}
 			
 			encoded = FALSE;
