@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -39,13 +39,14 @@
 
 extern gboolean _g_mime_enable_rfc2047_workarounds (void);
 
+GQuark gmime_gpgme_error_quark;
 GQuark gmime_error_quark;
 
 const guint gmime_major_version = GMIME_MAJOR_VERSION;
 const guint gmime_minor_version = GMIME_MINOR_VERSION;
 const guint gmime_micro_version = GMIME_MICRO_VERSION;
-const guint gmime_interface_age = 0;
-const guint gmime_binary_age = 0;
+const guint gmime_interface_age = GMIME_INTERFACE_AGE;
+const guint gmime_binary_age = GMIME_BINARY_AGE;
 
 static unsigned int initialized = 0;
 static guint32 enable = 0;
@@ -106,39 +107,11 @@ g_mime_init (guint32 flags)
 	
 	g_mime_iconv_init ();
 	
+	gmime_gpgme_error_quark = g_quark_from_static_string ("gmime-gpgme");
 	gmime_error_quark = g_quark_from_static_string ("gmime");
 	
 	/* register our GObject types with the GType system */
-	g_mime_cipher_context_get_type ();
-	g_mime_gpg_context_get_type ();
-	
-	g_mime_filter_get_type ();
-	g_mime_filter_basic_get_type ();
-	g_mime_filter_best_get_type ();
-	g_mime_filter_charset_get_type ();
-	g_mime_filter_crlf_get_type ();
-	g_mime_filter_enriched_get_type ();
-	g_mime_filter_from_get_type ();
-	g_mime_filter_gzip_get_type ();
-	g_mime_filter_html_get_type ();
-	g_mime_filter_md5_get_type ();
-	g_mime_filter_strip_get_type ();
-	g_mime_filter_windows_get_type ();
-	g_mime_filter_yenc_get_type ();
-	
-	g_mime_stream_get_type ();
-	g_mime_stream_buffer_get_type ();
-	g_mime_stream_cat_get_type ();
-	g_mime_stream_file_get_type ();
-	g_mime_stream_filter_get_type ();
-	g_mime_stream_fs_get_type ();
-	g_mime_stream_mem_get_type ();
-	g_mime_stream_mmap_get_type ();
-	g_mime_stream_null_get_type ();
-	
-	g_mime_parser_get_type ();
 	g_mime_message_get_type ();
-	g_mime_data_wrapper_get_type ();
 	g_mime_content_type_get_type ();
 	g_mime_content_disposition_get_type ();
 	
@@ -148,7 +121,6 @@ g_mime_init (guint32 flags)
 	internet_address_mailbox_get_type ();
 	
 	/* register our default mime object types */
-	g_mime_object_type_registry_init ();
 	g_mime_object_register_type ("*", "*", g_mime_part_get_type ());
 	g_mime_object_register_type ("multipart", "*", g_mime_multipart_get_type ());
 	g_mime_object_register_type ("multipart", "encrypted", g_mime_multipart_encrypted_get_type ());
@@ -172,7 +144,6 @@ g_mime_shutdown (void)
 	if (--initialized)
 		return;
 	
-	g_mime_object_type_registry_shutdown ();
 	g_mime_charset_map_shutdown ();
 	g_mime_iconv_shutdown ();
 }
