@@ -29,15 +29,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif
 #include <fcntl.h>
 #include <errno.h>
-#ifdef G_OS_WIN32
-#include <io.h>
-typedef int mode_t;
-#endif
 
 #ifdef HAVE_GETOPT_H
 #define _GNU_SOURCE
@@ -70,7 +64,7 @@ usage (const char *progname)
 static void
 version (const char *progname)
 {
-	printf ("%s - GMime %s\n", progname, VERSION);
+	printf ("%s - GMime %s\n", progname, GMIME_VERSION);
 }
 
 static FILE *
