@@ -78,9 +78,6 @@ static struct {
 	{ "Jeffrey \"fejj\" Stedfast <fejj@helixcode.com>",
 	  "Jeffrey fejj Stedfast <fejj@helixcode.com>",
 	  "Jeffrey fejj Stedfast <fejj@helixcode.com>" },
-	{ "\"Jeffrey \\\"fejj\\\" Stedfast\" <fejj@helixcode.com>",
-	  "Jeffrey \"fejj\" Stedfast <fejj@helixcode.com>",
-	  "\"Jeffrey \\\"fejj\\\" Stedfast\" <fejj@helixcode.com>" },
 	{ "\"Stedfast, Jeffrey\" <fejj@helixcode.com>",
 	  "\"Stedfast, Jeffrey\" <fejj@helixcode.com>",
 	  "\"Stedfast, Jeffrey\" <fejj@helixcode.com>" },
@@ -176,36 +173,10 @@ static struct {
 	{ "A Group(Some people):Chris Jones <c@(Chris's host.)public.example>, joe@example.org, John <jdoe@one.test> (my dear friend); (the end of the group)",
 	  "A Group: Chris Jones <c@public.example>, joe@example.org, John <jdoe@one.test>;",
 	  "A Group: Chris Jones <c@public.example>, joe@example.org, John <jdoe@one.test>;" },
-	/* The following tests cases are meant to test forgivingness
-	 * of the parser when it encounters unquoted specials in the
-	 * name component */
-	{ "Warren Worthington, Jr. <warren@worthington.com>",
-	  "\"Warren Worthington, Jr.\" <warren@worthington.com>",
-	  "\"Warren Worthington, Jr.\" <warren@worthington.com>" },
-	{ "dot.com <dot.com>",
-	  "\"dot.com\" <dot.com>",
-	  "\"dot.com\" <dot.com>" },
-	{ "=?UTF-8?Q?agatest123_\"test\"?= <agatest123@o2.pl>",
-	  "agatest123 test <agatest123@o2.pl>",
-	  "agatest123 test <agatest123@o2.pl>" },
-	{ "\"=?ISO-8859-2?Q?TEST?=\" <p@p.org>",
-	  "TEST <p@p.org>",
-	  "TEST <p@p.org>" },
-};
-
-static struct {
-	const char *input;
-	const char *display;
-	const char *encoded;
-} broken_addrspec[] = {
-	{ "\"Biznes=?ISO-8859-2?Q?_?=INTERIA.PL\"=?ISO-8859-2?Q?_?=<biuletyny@firma.interia.pl>",
-	  "\"Biznes INTERIA.PL \" <biuletyny@firma.interia.pl>",
-	  "\"Biznes INTERIA.PL\" <biuletyny@firma.interia.pl>",
-	},
 };
 
 static void
-test_addrspec (gboolean test_broken)
+test_addrspec (void)
 {
 	InternetAddressList *addrlist;
 	char *str;
@@ -222,12 +193,12 @@ test_addrspec (gboolean test_broken)
 			
 			str = internet_address_list_to_string (addrlist, FALSE);
 			if (strcmp (addrspec[i].display, str) != 0)
-				throw (exception_new ("display addr-spec %s does not match: %s", addrspec[i].display, str));
+				throw (exception_new ("display addr-spec does not match: %s", str));
 			g_free (str);
 			
 			str = internet_address_list_to_string (addrlist, TRUE);
 			if (strcmp (addrspec[i].encoded, str) != 0)
-				throw (exception_new ("encoded addr-spec %s does not match: %s", addrspec[i].encoded, str));
+				throw (exception_new ("encoded addr-spec does not match: %s", str));
 			
 			testsuite_check_passed ();
 		} catch (ex) {
@@ -238,36 +209,6 @@ test_addrspec (gboolean test_broken)
 		if (addrlist)
 			g_object_unref (addrlist);
 	}
-	
-	if (test_broken) {
-		for (i = 0; i < G_N_ELEMENTS (broken_addrspec); i++) {
-			addrlist = NULL;
-			str = NULL;
-			
-			testsuite_check ("broken_addrspec[%u]", i);
-			try {
-				if (!(addrlist = internet_address_list_parse_string (broken_addrspec[i].input)))
-					throw (exception_new ("could not parse addr-spec"));
-				
-				str = internet_address_list_to_string (addrlist, FALSE);
-				if (strcmp (broken_addrspec[i].display, str) != 0)
-					throw (exception_new ("display addr-spec %s does not match: %s", broken_addrspec[i].display, str));
-				g_free (str);
-				
-				str = internet_address_list_to_string (addrlist, TRUE);
-				if (strcmp (broken_addrspec[i].encoded, str) != 0)
-					throw (exception_new ("encoded addr-spec %s does not match: %s", broken_addrspec[i].encoded, str));
-				
-				testsuite_check_passed ();
-			} catch (ex) {
-				testsuite_check_failed ("broken_addrspec[%u]: %s", i, ex->message);
-			} finally;
-			
-			g_free (str);
-			if (addrlist)
-				g_object_unref (addrlist);
-		}
-	}
 }
 
 
@@ -591,7 +532,7 @@ int main (int argc, char **argv)
 	testsuite_init (argc, argv);
 	
 	testsuite_start ("addr-spec parser");
-	test_addrspec (FALSE);
+	test_addrspec ();
 	testsuite_end ();
 	
 	testsuite_start ("date parser");
@@ -614,7 +555,6 @@ int main (int argc, char **argv)
 	
 	g_mime_init (GMIME_ENABLE_RFC2047_WORKAROUNDS);
 	testsuite_start ("broken rfc2047 encoding/decoding");
-	test_addrspec (TRUE);
 	test_rfc2047 (TRUE);
 	testsuite_end ();
 	g_mime_shutdown ();
