@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,8 +22,6 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -33,7 +31,6 @@
 #include <sys/mman.h>
 #endif
 #include <unistd.h>
-#include <dirent.h>
 #include <fcntl.h>
 #include <errno.h>
 
@@ -55,7 +52,7 @@ streams_match (GMimeStream **streams, const char *filename)
 	size_t nread, size;
 	ssize_t n;
 	
-	v(fprintf (stdout, "Matching original stream (%" G_GINT64_FORMAT " -> %" G_GINT64_FORMAT ") with %s (%" G_GINT64_FORMAT ", %" G_GINT64_FORMAT ")... ",
+	v(fprintf (stdout, "Matching original stream (%lld -> %lld) with %s (%lld, %lld)... ",
 		   streams[0]->position, streams[0]->bound_end, filename,
 		   streams[1]->position, streams[1]->bound_end));
 	
@@ -79,19 +76,19 @@ streams_match (GMimeStream **streams, const char *filename)
 		nread = 0;
 		totalread += n;
 		
-		d(fprintf (stderr, "read %" G_GSIZE_FORMAT " bytes from stream[0]\n", size));
+		d(fprintf (stderr, "read %zu bytes from stream[0]\n", size));
 		
 		do {
 			if ((n = g_mime_stream_read (streams[1], dbuf + nread, size - nread)) <= 0) {
-				d(fprintf (stderr, "stream[1] read() returned %" G_GSSIZE_FORMAT ", EOF\n", n));
+				d(fprintf (stderr, "stream[1] read() returned %zd, EOF\n", n));
 				break;
 			}
-			d(fprintf (stderr, "read %" G_GSSIZE_FORMAT " bytes from stream[1]\n", n));
+			d(fprintf (stderr, "read %zd bytes from stream[1]\n", n));
 			nread += n;
 		} while (nread < size);
 		
 		if (nread < size) {
-			sprintf (errstr, "Error: `%s' appears to be truncated, short %" G_GSIZE_FORMAT "+ bytes\n",
+			sprintf (errstr, "Error: `%s' appears to be truncated, short %zu+ bytes\n",
 				 filename, size - nread);
 			goto fail;
 		}
@@ -100,7 +97,7 @@ streams_match (GMimeStream **streams, const char *filename)
 			sprintf (errstr, "Error: `%s': content does not match\n", filename);
 			goto fail;
 		} else {
-			d(fprintf (stderr, "%" G_GSIZE_FORMAT " bytes identical\n", size));
+			d(fprintf (stderr, "%zu bytes identical\n", size));
 		}
 	}
 	
@@ -132,11 +129,8 @@ test_stream_gets (GMimeStream *stream, const char *filename)
 	char sbuf[100], rbuf[100];
 	ssize_t slen;
 	FILE *fp;
-
-	/* '0x1a' character is treated as EOF (Ctrl+Z) on Windows if file is opened in text mode,
-	 *  thus it's opened in binary mode.
-	 */
-	if (!(fp = fopen (filename, "r+b")))
+	
+	if (!(fp = fopen (filename, "r+")))
 		throw (exception_new ("could not open `%s': %s", filename, g_strerror (errno)));
 	
 	while (!g_mime_stream_eos (stream)) {
@@ -151,8 +145,8 @@ test_stream_gets (GMimeStream *stream, const char *filename)
 	fclose (fp);
 	
 	if (strcmp (sbuf, rbuf) != 0) {
-		v(fprintf (stderr, "\tstream: \"%s\" (%" G_GSIZE_FORMAT ")\n", sbuf, strlen (sbuf)));
-		v(fprintf (stderr, "\treal:   \"%s\" (%" G_GSIZE_FORMAT ")\n", rbuf, strlen (rbuf)));
+		v(fprintf (stderr, "\tstream: \"%s\" (%zu)\n", sbuf, strlen (sbuf)));
+		v(fprintf (stderr, "\treal:   \"%s\" (%zu)\n", rbuf, strlen (rbuf)));
 		throw (exception_new ("streams did not match"));
 	}
 }
@@ -163,7 +157,7 @@ test_stream_buffer_gets (const char *filename)
 	GMimeStream *stream, *buffered = NULL;
 	int fd;
 	
-	if ((fd = open (filename, O_RDONLY)) == -1) {
+	if ((fd = open (filename, O_RDONLY, 0)) == -1) {
 		v(fprintf (stderr, "failed to open %s", filename));
 		return;
 	}
@@ -208,7 +202,7 @@ test_stream_mem (const char *filename)
 	GMimeStream *stream, *fstream;
 	int fd;
 	
-	if ((fd = open (filename, O_RDONLY)) == -1) {
+	if ((fd = open (filename, O_RDONLY, 0)) == -1) {
 		v(fprintf (stderr, "failed to open %s: %s\n", filename, g_strerror (errno)));
 		return;
 	}
@@ -251,10 +245,10 @@ check_stream_fs (const char *input, const char *output, const char *filename, gi
 	Exception *ex = NULL;
 	int fd[2];
 	
-	if ((fd[0] = open (input, O_RDONLY)) == -1)
+	if ((fd[0] = open (input, O_RDONLY, 0)) == -1)
 		return FALSE;
 	
-	if ((fd[1] = open (output, O_RDONLY)) == -1) {
+	if ((fd[1] = open (output, O_RDONLY, 0)) == -1) {
 		close (fd[0]);
 		return FALSE;
 	}
@@ -310,7 +304,7 @@ check_stream_file (const char *input, const char *output, const char *filename,
 	return TRUE;
 }
 
-#ifdef HAVE_SYS_MMAN_H
+#ifdef HAVE_MMAP
 static gboolean
 check_stream_mmap (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
 {
@@ -318,10 +312,10 @@ check_stream_mmap (const char *input, const char *output, const char *filename,
 	Exception *ex = NULL;
 	int fd[2];
 	
-	if ((fd[0] = open (input, O_RDONLY)) == -1)
+	if ((fd[0] = open (input, O_RDONLY, 0)) == -1)
 		return FALSE;
 	
-	if ((fd[1] = open (output, O_RDONLY)) == -1) {
+	if ((fd[1] = open (output, O_RDONLY, 0)) == -1) {
 		close (fd[0]);
 		return FALSE;
 	}
@@ -343,7 +337,7 @@ check_stream_mmap (const char *input, const char *output, const char *filename,
 	
 	return TRUE;
 }
-#endif
+#endif /* HAVE_MMAP */
 
 static gboolean
 check_stream_buffer_block (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
@@ -352,10 +346,10 @@ check_stream_buffer_block (const char *input, const char *output, const char *fi
 	Exception *ex = NULL;
 	int fd[2];
 	
-	if ((fd[0] = open (input, O_RDONLY)) == -1)
+	if ((fd[0] = open (input, O_RDONLY, 0)) == -1)
 		return FALSE;
 	
-	if ((fd[1] = open (output, O_RDONLY)) == -1) {
+	if ((fd[1] = open (output, O_RDONLY, 0)) == -1) {
 		close (fd[0]);
 		return FALSE;
 	}
@@ -387,10 +381,10 @@ check_stream_buffer_cache (const char *input, const char *output, const char *fi
 	Exception *ex = NULL;
 	int fd[2];
 	
-	if ((fd[0] = open (input, O_RDONLY)) == -1)
+	if ((fd[0] = open (input, O_RDONLY, 0)) == -1)
 		return FALSE;
 	
-	if ((fd[1] = open (output, O_RDONLY)) == -1) {
+	if ((fd[1] = open (output, O_RDONLY, 0)) == -1) {
 		close (fd[0]);
 		return FALSE;
 	}
@@ -415,6 +409,37 @@ check_stream_buffer_cache (const char *input, const char *output, const char *fi
 	return TRUE;
 }
 
+static gboolean
+check_stream_gio (const char *input, const char *output, const char *filename, gint64 start, gint64 end)
+{
+	GMimeStream *streams[2];
+	Exception *ex = NULL;
+	GFile *file;
+	int fd;
+	
+	if (!(file = g_file_new_for_path (input)))
+		return FALSE;
+	
+	if ((fd = open (output, O_RDONLY, 0)) == -1) {
+		g_object_unref (file);
+		return FALSE;
+	}
+	
+	streams[0] = g_mime_stream_gio_new_with_bounds (file, start, end);
+	streams[1] = g_mime_stream_fs_new (fd);
+	
+	if (!streams_match (streams, filename))
+		ex = exception_new ("GMimeStreamBuffer (Cache Mode) streams did not match for `%s'", filename);
+	
+	g_object_unref (streams[0]);
+	g_object_unref (streams[1]);
+	
+	if (ex != NULL)
+		throw (ex);
+	
+	return TRUE;
+}
+
 
 typedef gboolean (* checkFunc) (const char *, const char *, const char *, gint64, gint64);
 
@@ -424,18 +449,19 @@ static struct {
 } checks[] = {
 	{ "GMimeStreamFs",                  check_stream_fs           },
 	{ "GMimeStreamFile",                check_stream_file         },
-#ifdef HAVE_SYS_MMAN_H
+#ifdef HAVE_MMAP
 	{ "GMimeStreamMmap",                check_stream_mmap         },
-#endif
+#endif /* HAVE_MMAP */
 	{ "GMimeStreamBuffer (block mode)", check_stream_buffer_block },
 	{ "GMimeStreamBuffer (cache mode)", check_stream_buffer_cache },
+	{ "GMimeStreamGIO",                 check_stream_gio          },
 };
 
 static void
-test_streams (DIR *dir, const char *datadir, const char *filename)
+test_streams (GDir *dir, const char *datadir, const char *filename)
 {
 	char inpath[256], outpath[256], *p, *q, *o;
-	struct dirent *dent;
+	const char *dent, *d;
 	gint64 start, end;
 	size_t n;
 	guint i;
@@ -454,42 +480,42 @@ test_streams (DIR *dir, const char *datadir, const char *filename)
 	
 	n = strlen (filename);
 	
-	while ((dent = readdir (dir))) {
-		if (strncmp (dent->d_name, filename, n) != 0 || dent->d_name[n] != '_')
+	while ((dent = g_dir_read_name (dir))) {
+		if (strncmp (dent, filename, n) != 0 || dent[n] != ':')
 			continue;
 		
-		p = dent->d_name + n + 1;
-		if ((start = strtol (p, &o, 10)) < 0 || *o != ',')
+		d = dent + n + 1;
+		if ((start = strtol (d, &o, 10)) < 0 || *o != ',')
 			continue;
 		
-		p = o + 1;
+		d = o + 1;
 		
-		if ((((end = strtol (p, &o, 10)) < start) && end != -1) || *o != '\0')
+		if ((((end = strtol (d, &o, 10)) < start) && end != -1) || *o != '\0')
 			continue;
 		
-		strcpy (q, dent->d_name);
+		strcpy (q, dent);
 		
 		for (i = 0; i < G_N_ELEMENTS (checks); i++) {
-			testsuite_check ("%s on `%s'", checks[i].what, dent->d_name);
+			testsuite_check ("%s on `%s'", checks[i].what, dent);
 			try {
-				if (!checks[i].check (inpath, outpath, dent->d_name, start, end)) {
+				if (!checks[i].check (inpath, outpath, dent, start, end)) {
 					testsuite_check_warn ("%s could not open `%s'",
-							      checks[i].what, dent->d_name);
+							      checks[i].what, dent);
 				} else {
 					testsuite_check_passed ();
 				}
 			} catch (ex) {
 				testsuite_check_failed ("%s on `%s' failed: %s", checks[i].what,
-							dent->d_name, ex->message);
+							dent, ex->message);
 			} finally;
 		}
 	}
 	
-	rewinddir (dir);
+	g_dir_rewind (dir);
 }
 
 
-static size_t
+static void
 gen_random_stream (GMimeStream *stream)
 {
 	size_t nwritten, buflen, total = 0, size, i;
@@ -498,7 +524,7 @@ gen_random_stream (GMimeStream *stream)
 	
 	/* read between 4k and 14k bytes */
 	size = 4096 + (size_t) (10240.0 * (rand () / (RAND_MAX + 1.0)));
-	v(fprintf (stdout, "Generating %" G_GSIZE_FORMAT " bytes of random data... ", size));
+	v(fprintf (stdout, "Generating %zu bytes of random data... ", size));
 	v(fflush (stdout));
 	
 	while (total < size) {
@@ -522,8 +548,6 @@ gen_random_stream (GMimeStream *stream)
 	g_mime_stream_reset (stream);
 	
 	v(fputs ("done\n", stdout));
-
-	return size;
 }
 
 static int
@@ -531,7 +555,9 @@ gen_test_data (const char *datadir, char **stream_name)
 {
 	GMimeStream *istream, *ostream, *stream;
 	char input[256], output[256], *name, *p;
-	gint64 start, end, len, size;
+	gint64 start, end;
+	struct stat st;
+	size_t len;
 	int fd, i;
 	
 	srand (time (NULL));
@@ -557,23 +583,29 @@ gen_test_data (const char *datadir, char **stream_name)
 	
 	*p++ = G_DIR_SEPARATOR;
 	p = g_stpcpy (p, name);
-	*p++ = '_';
+	*p++ = ':';
 	
 	istream = g_mime_stream_fs_new (fd);
-	size = gen_random_stream (istream);
+	gen_random_stream (istream);
+	
+	if (stat (input, &st) == -1 || !S_ISREG (st.st_mode)) {
+		g_object_unref (istream);
+		unlink (input);
+		return -1;
+	}
 	
 	for (i = 0; i < 64; i++) {
 	retry:
-		start = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
-		len = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
-		if (start + len > size) {
-			len = size - start;
+		start = (gint64) (st.st_size * (rand () / (RAND_MAX + 1.0)));
+		len = (size_t) (st.st_size * (rand () / (RAND_MAX + 1.0)));
+		if (start + len > st.st_size) {
+			len = st.st_size - start;
 			end = -1;
 		} else {
 			end = start + len;
 		}
 		
-		sprintf (p, "%" G_GINT64_FORMAT ",%" G_GINT64_FORMAT, start, end);
+		sprintf (p, "%lld,%lld", start, end);
 		
 		if ((fd = open (output, O_CREAT | O_EXCL | O_TRUNC | O_WRONLY, 0666)) == -1)
 			goto retry;
@@ -594,9 +626,9 @@ int main (int argc, char **argv)
 	const char *datadir = "data/streams";
 	gboolean gen_data = TRUE;
 	char *stream_name = NULL;
-	struct dirent *dent;
 	char path[256], *p;
-	DIR *dir, *outdir;
+	GDir *dir, *outdir;
+	const char *dent;
 	int i;
 	
 	g_mime_init (0);
@@ -616,9 +648,9 @@ int main (int argc, char **argv)
 	*p++ = G_DIR_SEPARATOR;
 	strcpy (p, "output");
 	
-	if (!(outdir = opendir (path))) {
+	if (!(outdir = g_dir_open (path, 0, NULL))) {
 		if (gen_test_data (datadir, &stream_name) == -1 ||
-		    !(outdir = opendir (path)))
+		    !(outdir = g_dir_open (path, 0, NULL)))
 			goto exit;
 		
 		gen_data = FALSE;
@@ -626,10 +658,10 @@ int main (int argc, char **argv)
 	
 	p = g_stpcpy (p, "input");
 	
-	if (!(dir = opendir (path))) {
+	if (!(dir = g_dir_open (path, 0, NULL))) {
 		if (!gen_data || gen_test_data (datadir, &stream_name) == -1 ||
-		    !(dir = opendir (path))) {
-			closedir (outdir);
+		    !(dir = g_dir_open (path, 0, NULL))) {
+			g_dir_close (outdir);
 			goto exit;
 		}
 		
@@ -637,15 +669,15 @@ int main (int argc, char **argv)
 	}
 	
 	if (gen_data) {
-		while ((dent = readdir (dir))) {
-			if (dent->d_name[0] == '.' || !strcmp (dent->d_name, "README"))
+		while ((dent = g_dir_read_name (dir))) {
+			if (dent[0] == '.' || !strcmp (dent, "README"))
 				continue;
 			
 			gen_data = FALSE;
 			break;
 		}
 		
-		rewinddir (dir);
+		g_dir_rewind (dir);
 		
 		if (gen_data && gen_test_data (datadir, &stream_name) == -1)
 			goto exit;
@@ -654,13 +686,13 @@ int main (int argc, char **argv)
 	*p++ = G_DIR_SEPARATOR;
 	*p = '\0';
 	
-	while ((dent = readdir (dir))) {
-		if (dent->d_name[0] == '.' || !strcmp (dent->d_name, "README"))
+	while ((dent = g_dir_read_name (dir))) {
+		if (dent[0] == '.' || !strcmp (dent, "README"))
 			continue;
 		
-		test_streams (outdir, datadir, dent->d_name);
+		test_streams (outdir, datadir, dent);
 		
-		strcpy (p, dent->d_name);
+		strcpy (p, dent);
 		test_stream_buffer_gets (path);
 	}
 	
@@ -674,10 +706,10 @@ int main (int argc, char **argv)
 		p = g_stpcpy (p, "output");
 		*p++ = G_DIR_SEPARATOR;
 		
-		rewinddir (outdir);
-		while ((dent = readdir (outdir))) {
-			if (!strncmp (dent->d_name, stream_name, strlen (stream_name))) {
-				strcpy (p, dent->d_name);
+		g_dir_rewind (outdir);
+		while ((dent = g_dir_read_name (outdir))) {
+			if (!strncmp (dent, stream_name, strlen (stream_name))) {
+				strcpy (p, dent);
 				unlink (path);
 			}
 		}
@@ -685,8 +717,8 @@ int main (int argc, char **argv)
 		g_free (stream_name);
 	}
 	
-	closedir (outdir);
-	closedir (dir);
+	g_dir_close (outdir);
+	g_dir_close (dir);
 	
 exit:
 	
